@@ -9,17 +9,14 @@ use Catalyst qw/
 
   Authentication
   Authorization::Roles
-
   Session
   Session::Store::FastMmap
-  Session::State::Cookie    
+  Session::State::Cookie
   /;
-  
-require App::Cinema::Event;
-#use App::Cinema::Schema::Result::GenreItems as => 'GenreItems';
-#use App::Cinema::Schema::Result::Users as => 'Users';
 
-our $VERSION = '1.14';
+BEGIN {
+	our $VERSION = '1.14';
+}
 
 __PACKAGE__->setup;
 
@@ -31,4 +28,4 @@ App::Cinema - A simple website to demo how easy to provide CRUD via Catalyst fra
 
 =head1 AUTHOR
 
-Jeff Mo - <mo0118@gmail.com>
\ No newline at end of file
+Jeff Mo - <mo0118@gmail.com>
